==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/LibraryBrowser/ts/LibraryBrowser_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>Favorites</name>
    <message>
        <source>Item &apos;%1&apos; has been added to your favorites.</source>
        <translation type="obsolete">Item &apos;%1&apos; foi adicionado aos seus favoritos.</translation>
    </message>
</context>
<context>
    <name>LibraryBrowser</name>
    <message>
        <location filename="../LibraryBrowser.js" line="+69"/>
        <source>audience</source>
        <translation>Público</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>creator</source>
        <translation>Autor</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>dimension</source>
        <translation>Dimensão</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>levelOfDetail</source>
        <translation>Nível de detalhe</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>license</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>perspective</source>
        <translation>Perspectiva</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>presentation</source>
        <translation>Apresentação</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>publisher</source>
        <translation>Editor</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>subject</source>
        <translation>Sujeito</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1105"/>
        <location filename="../LibraryBrowserInit.js" line="+18"/>
        <source>Library Browser</source>
        <translation>Navegador de biblioteca</translation>
    </message>
    <message>
        <location line="-1097"/>
        <source>Icon</source>
        <translation>Ícone</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>List</source>
        <translation>Lista</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Choose Source Folder</source>
        <translation>Escolha a pasta de origem</translation>
    </message>
    <message>
        <location line="+652"/>
        <source>Page %1 of %2</source>
        <translation>Page %1 dos %2</translation>
    </message>
    <message>
        <location line="+219"/>
        <source>Updating icons...</source>
        <translation>Regenerar icons...</translation>
    </message>
    <message>
        <location line="+193"/>
        <source>File:</source>
        <translation>Ficheiro:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Folder:</source>
        <translation>Diretório:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>License:</source>
        <translation>Licença:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attribute as:</source>
        <translation>Atribuição:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Creator:</source>
        <translation>Autor:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Updating library index:</source>
        <translation>Atualização do índice:</translation>
    </message>
    <message>
        <source>Updating index...</source>
        <translation type="obsolete">Atualização do índice...</translation>
    </message>
    <message>
        <location line="-218"/>
        <location line="+219"/>
        <source>Abort</source>
        <translation>Abortar</translation>
    </message>
    <message>
        <source>Updating index:</source>
        <translation type="obsolete">Atualização do índice:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>DB error</source>
        <translation>Erro de DB</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</source>
        <translation>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</translation>
    </message>
    <message>
        <location line="+446"/>
        <source>&amp;Insert</source>
        <translation>&amp;Inserir</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Edit Script File...</source>
        <translation>&amp;Editar arquivo de script...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Open &amp;SVG File...</source>
        <translation>Abrir arquivo &amp;SVG...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Open...</source>
        <translation>&amp;Abra...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;Edit...</source>
        <translation>&amp;Edição...</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>File Browser</source>
        <translation>Ficheiro</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Show in %1...</source>
        <translation>&amp;Mostrar com %1...</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>&amp;Remove from Favorites</source>
        <translation>&amp;Remover dos favoritos</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Add to Favorites</source>
        <translation>&amp;Adicionar aos favoritos</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>&amp;Regenerate Icon</source>
        <translation>Regenerar &amp;ícone</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Regenerate Icons</source>
        <translation>&amp;Regenerar icons</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">Preferências</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Synchronization</source>
        <translation>Sincronização</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Update search index on startup</source>
        <translation>Atualize índice de pesquisa na inicialização</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display Options</source>
        <translation>Opções de visualização</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Icon Size:</source>
        <translation>Tamanho ícone:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>View Mode:</source>
        <translation>Modo de exibição:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Number of items
shown in search results:</source>
        <translation>Número de itens mostrados
nos resultados de busca:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Library Sources</source>
        <translation>Fontes biblioteca</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Add...</source>
        <translation>Adicionar...</translation>
    </message>
    <message>
        <source>Add ...</source>
        <translation type="obsolete">Adicionar...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Up</source>
        <translation>Acima</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Down</source>
        <translation>Baixo</translation>
    </message>
    <message>
        <location filename="../LibraryBrowserInit.js" line="-10"/>
        <source>&amp;Library Browser</source>
        <translation>Navegador de &amp;Biblioteca</translation>
    </message>
</context>
<context>
    <name>LibraryBrowserForm</name>
    <message>
        <location filename="../LibraryBrowser.ui" line="+28"/>
        <source>File System</source>
        <translation>Sistema de arquivos</translation>
    </message>
    <message>
        <location line="+252"/>
        <source>Favorites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <location line="-201"/>
        <source>Tags</source>
        <translation>Tags</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Look for:</source>
        <translation>Procurar:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Find</source>
        <translation>Procurar</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Reset tag selection</source>
        <translation>Restaurar</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>about:blank</source>
        <translation>about:blank</translation>
    </message>
    <message>
        <location line="+157"/>
        <source>Update DB from file system</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>0</source>
        <translation>0</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/LibraryBrowser/ts/LibraryBrowser_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Favorites</name>
    <message>
        <source>Item &apos;%1&apos; has been added to your favorites.</source>
        <translation type="obsolete">Item &apos;%1&apos; foi adicionado aos seus favoritos.</translation>
    </message>
</context>
<context>
    <name>LibraryBrowser</name>
    <message>
        <location filename="../LibraryBrowser.js" line="+71"/>
        <source>audience</source>
        <translation>público</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>creator</source>
        <translation>autor</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>dimension</source>
        <translation>dimensão</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>levelOfDetail</source>
        <translation>NíveldeDetalhe</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>license</source>
        <translation>licença</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>perspective</source>
        <translation>perspectiva</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>presentation</source>
        <translation>apresentação</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>publisher</source>
        <translation>editor</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>subject</source>
        <translation>sujeito</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>title</source>
        <translation>título</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1153"/>
        <location filename="../LibraryBrowserInit.js" line="+19"/>
        <source>Library Browser</source>
        <translation>Navegador de Biblioteca</translation>
    </message>
    <message>
        <location line="-1145"/>
        <source>Icon</source>
        <translation>Ícone</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>List</source>
        <translation>Lista</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Choose Source Folder</source>
        <translation>Escolha a Pasta de Origem</translation>
    </message>
    <message>
        <location line="+685"/>
        <source>Page %1 of %2</source>
        <translation>Página %1 de %2</translation>
    </message>
    <message>
        <location line="+235"/>
        <source>Updating icons...</source>
        <translation>Atualizando ícones...</translation>
    </message>
    <message>
        <location line="+193"/>
        <source>File:</source>
        <translation>Arquivo:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Folder:</source>
        <translation>Diretório:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>License:</source>
        <translation>Licença:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attribute as:</source>
        <translation>Atribuição:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Creator:</source>
        <translation>Autor:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Updating library index:</source>
        <translation>Atualizando o índice da Biblioteca:</translation>
    </message>
    <message>
        <source>Updating index...</source>
        <translation type="obsolete">Atualização do índice...</translation>
    </message>
    <message>
        <location line="-218"/>
        <location line="+219"/>
        <source>Abort</source>
        <translation>Aborte</translation>
    </message>
    <message>
        <source>Updating index:</source>
        <translation type="obsolete">Atualização do índice:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>DB error</source>
        <translation>Erro de DB</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin LibraryBrowser: cannot connect to DB.
Driver error: %1
Database error: %2
Database file: %3
Library browser will not be available.</source>
        <translation>Plugin LibraryBrowser: não posso me conectar ao BD.
Erro de driver: %1
Erro de Banco de Dados: %2
Arquivo de Banco de dDados: %3
Navegador de Biblioteca não estará disponível.</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Source removed from part library: %1</source>
        <translation>O fonte foi removido da Biblioteca: %1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Force database update.</source>
        <translation>Force a atualização da base de dados.</translation>
    </message>
    <message>
        <location line="+393"/>
        <source>&amp;Insert</source>
        <translation>&amp;Insira</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Edit Script File...</source>
        <translation>&amp;Edite o Arquivo de Script...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Open &amp;SVG File...</source>
        <translation>Abra um Arquivo &amp;SVG...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Open...</source>
        <translation>&amp;Abra...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;Edit...</source>
        <translation>&amp;Edite...</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>File Browser</source>
        <translation>Navegador de Arquivos</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Show in %1...</source>
        <translation>&amp;Exiba em %1...</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>&amp;Remove from Favorites</source>
        <translation>&amp;Remova dos Favoritos</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Add to Favorites</source>
        <translation>&amp;Adicione aos Favoritos</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>&amp;Regenerate Icon</source>
        <translation>Regenere o &amp;ícone</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Regenerate Icons</source>
        <translation>&amp;Regenere Ícones</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">Preferências</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Synchronization</source>
        <translation>Sincronização</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Update search index on startup</source>
        <translation>Atualize índice de pesquisa na inicialização</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display Options</source>
        <translation>Opções de Visualização</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Icon Size:</source>
        <translation>Tamanho do Ícone:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>View Mode:</source>
        <translation>Modo de Exibição:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Number of items
shown in search results:</source>
        <translation>Número de itens mostrados
nos resultados de busca:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Library Sources</source>
        <translation>Fontes de Biblioteca</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Add...</source>
        <translation>Adicione...</translation>
    </message>
    <message>
        <source>Add ...</source>
        <translation type="obsolete">Adicionar...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Remove</source>
        <translation>Remova</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Up</source>
        <translation>Acima</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Down</source>
        <translation>Abaixo</translation>
    </message>
    <message>
        <location filename="../LibraryBrowserInit.js" line="-11"/>
        <source>&amp;Library Browser</source>
        <translation>Navegador de &amp;Biblioteca</translation>
    </message>
</context>
<context>
    <name>LibraryBrowserForm</name>
    <message>
        <location filename="../LibraryBrowser.ui" line="+28"/>
        <source>File System</source>
        <translation>Sistema de Arquivos</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Search</source>
        <translation>Procurar</translation>
    </message>
    <message>
        <location line="+197"/>
        <source>Favorites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation type="vanished">Rótulos</translation>
    </message>
    <message>
        <location line="-174"/>
        <source>Look for:</source>
        <translation>Procure por:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Clear</source>
        <translation>Limpe</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Find</source>
        <translation>Procure</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Reset tag selection</source>
        <translation>Resete a seleção de rótulos</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">sobre:branco</translation>
    </message>
    <message>
        <location line="+162"/>
        <source>Insert selected item into drawing</source>
        <translation>Insira o item selecionado no desenho</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Update DB from file system</source>
        <translation>Atualizar o BD a partir do sistema de arquivos</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>0</source>
        <translation>0</translation>
    </message>
</context>
</TS>
